==> tencentcloud-sdk-java-3.1.87-sources.jar: com/tencentcloudapi/taf/v20200210/models/SendTrafficSecuritySmsMessageRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.taf.v20200210.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SendTrafficSecuritySmsMessageRequest extends AbstractModel{

    /**
    * 业务入参
    */
    @SerializedName("BspData")
    @Expose
    private InputSendTrafficSecuritySmsMsg BspData;

    /**
     * Get 业务入参 
     * @return BspData 业务入参
     */
    public InputSendTrafficSecuritySmsMsg getBspData() {
        return this.BspData;
    }

    /**
     * Set 业务入参
     * @param BspData 业务入参
     */
    public void setBspData(InputSendTrafficSecuritySmsMsg BspData) {
        this.BspData = BspData;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "BspData.", this.BspData);

    }
}

==> tencentcloud-sdk-java-3.1.264-sources.jar: com/tencentcloudapi/taf/v20200210/models/SendTrafficSecuritySmsMessageRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.taf.v20200210.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SendTrafficSecuritySmsMessageRequest extends AbstractModel{

    /**
    * 业务入参
    */
    @SerializedName("BspData")
    @Expose
    private InputSendTrafficSecuritySmsMsg BspData;

    /**
     * Get 业务入参 
     * @return BspData 业务入参
     */
    public InputSendTrafficSecuritySmsMsg getBspData() {
        return this.BspData;
    }

    /**
     * Set 业务入参
     * @param BspData 业务入参
     */
    public void setBspData(InputSendTrafficSecuritySmsMsg BspData) {
        this.BspData = BspData;
    }

    public SendTrafficSecuritySmsMessageRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public SendTrafficSecuritySmsMessageRequest(SendTrafficSecuritySmsMessageRequest source) {
        if (source.BspData != null) {
            this.BspData = new InputSendTrafficSecuritySmsMsg(source.BspData);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "BspData.", this.BspData);

    }
}
